@@ -1,5 +1,5 @@
 package App::ansifold;
-our $VERSION = "1.24";
+our $VERSION = "1.25";
 
 use v5.14;
 use warnings;
@@ -40,11 +40,11 @@ use Getopt::EX::Hashed 'has'; {
     has ambiguous  => '   =s  ' ;
     has paragraph  => ' p +   ' , default => 0;
     has refill     => ' r +   ' , default => 0;
-    has separate   => '   =s  ' ;
+    has separate   => '   =s  ' , default => $DEFAULT_SEPARATE;
     has linebreak  => '   =s  ' , alias   => 'lb';
     has runin      => '   =i  ' , min => 0, default => 4;
     has runout     => '   =i  ' , min => 0, default => 4;
-    has run        => '   =i  ' , min => 0;
+    has runlen     => '   =i  ' , min => 0;
     has nonewline  => ' n     ' ;
     has smart      => ' s !   ' ;
     has expand     => ' x :-1 ' , default => $DEFAULT_EXPAND;
@@ -91,8 +91,12 @@ use Getopt::EX::Hashed 'has'; {
 	    };
 	};
 
-    ### --run
-    has '+run' => sub {
+    ### --runlen
+    has '+runlen' => sub {
+	$_->runin = $_->runout = $_[1];
+    };
+    # for backward compatibility, would be deplicated
+    has 'run' => sub {
 	$_->runin = $_->runout = $_[1];
     };
 
@@ -135,7 +139,7 @@ sub options {
 
     ## --colrm
     if ($app->colrm) {
-	$app->separate //= '';
+	$app->separate = '';
 	my @params;
 	while (@ARGV > 0 and $ARGV[0] =~ /^\d+$/) {
 	    push @params, shift @ARGV;
@@ -144,7 +148,7 @@ sub options {
     }
     ## --cut
     elsif ($app->cut) {
-	$app->separate //= '';
+	$app->separate = '';
 	@{$app->width} = cut_to_width($app->cut);
     }
 
